import { ServiceProto } from "tsrpc-proto";
import { ReqLogin, ResLogin } from "./account/PtlLogin";
import { MsgChat } from "./MsgChat";
import { MsgExit } from "./room/MsgExit";
import { MsgGoToGame } from "./room/MsgGoToGame";
import { ReqCreate, ResCreate } from "./room/PtlCreate";
import { ReqExit, ResExit } from "./room/PtlExit";
import { ReqJoin, ResJoin } from "./room/PtlJoin";
import { ReqList, ResList } from "./room/PtlList";

export interface ServiceType {
	api: {
		"account/Login": {
			req: ReqLogin,
			res: ResLogin
		},
		"room/Create": {
			req: ReqCreate,
			res: ResCreate
		},
		"room/Exit": {
			req: ReqExit,
			res: ResExit
		},
		"room/Join": {
			req: ReqJoin,
			res: ResJoin
		},
		"room/List": {
			req: ReqList,
			res: ResList
		}
	},
	msg: {
		"Chat": MsgChat,
		"room/Exit": MsgExit,
		"room/GoToGame": MsgGoToGame
	}
}

export const serviceProto: ServiceProto<ServiceType> = {
	"version": 10,
	"services": [
		{
			"id": 4,
			"name": "account/Login",
			"type": "api"
		},
		{
			"id": 0,
			"name": "Chat",
			"type": "msg"
		},
		{
			"id": 10,
			"name": "room/Exit",
			"type": "msg"
		},
		{
			"id": 11,
			"name": "room/GoToGame",
			"type": "msg"
		},
		{
			"id": 6,
			"name": "room/Create",
			"type": "api"
		},
		{
			"id": 7,
			"name": "room/Exit",
			"type": "api"
		},
		{
			"id": 8,
			"name": "room/Join",
			"type": "api"
		},
		{
			"id": 9,
			"name": "room/List",
			"type": "api"
		}
	],
	"types": {
		"account/PtlLogin/ReqLogin": {
			"type": "Interface",
			"properties": [
				{
					"id": 0,
					"name": "name",
					"type": {
						"type": "String"
					}
				}
			]
		},
		"account/PtlLogin/ResLogin": {
			"type": "Number"
		},
		"MsgChat/MsgChat": {
			"type": "Interface",
			"properties": [
				{
					"id": 0,
					"name": "content",
					"type": {
						"type": "String"
					}
				},
				{
					"id": 1,
					"name": "time",
					"type": {
						"type": "Date"
					}
				}
			]
		},
		"room/MsgExit/MsgExit": {
			"type": "Number"
		},
		"room/MsgGoToGame/MsgGoToGame": {
			"type": "Number"
		},
		"room/PtlCreate/ReqCreate": {
			"type": "Interface",
			"properties": [
				{
					"id": 1,
					"name": "null",
					"type": {
						"type": "String"
					}
				}
			]
		},
		"room/PtlCreate/ResCreate": {
			"type": "Number"
		},
		"room/PtlExit/ReqExit": {
			"type": "Interface",
			"properties": [
				{
					"id": 0,
					"name": "null",
					"type": {
						"type": "String"
					}
				}
			]
		},
		"room/PtlExit/ResExit": {
			"type": "Number"
		},
		"room/PtlJoin/ReqJoin": {
			"type": "Interface",
			"properties": [
				{
					"id": 0,
					"name": "roomId",
					"type": {
						"type": "Number"
					}
				}
			]
		},
		"room/PtlJoin/ResJoin": {
			"type": "Number"
		},
		"room/PtlList/ReqList": {
			"type": "Interface",
			"properties": [
				{
					"id": 0,
					"name": "null",
					"type": {
						"type": "String"
					}
				}
			]
		},
		"room/PtlList/ResList": {
			"type": "Array",
			"elementType": {
				"type": "Any"
			}
		}
	}
};